//	StandardPhilStatusbar.cpp - Standard statusbar Component for Phil.
//	--------------------------------------------------------------------------
//	This file is part of 'Phil', a very simple file manager/browser for the
//	JUCE library.
//	Copyright (C) 2005-2006  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------

#include <juce.h>
#include "StandardPhilStatusbar.h"
#include "PhilComponent.h"

//----------------------------------------------------------------------------
StandardPhilStatusbar::StandardPhilStatusbar(Phil *parentComponent):
Component(),
parent(parentComponent)
{
	addAndMakeVisible(pathLabel = new Label(T("path"),
											SystemStats::getUserHomeDirectory()));
	pathLabel->setColours(parent->getTextColour(),
						  Colours::transparentBlack,
						  parent->getTextColour(),
						  Colours::transparentBlack,
						  Colours::transparentBlack,
						  Colours::transparentBlack);
	addAndMakeVisible(miscLabel = new Label(T("misc"),
											T("(empty)")));
	miscLabel->setColours(parent->getTextColour(),
						  Colours::transparentBlack,
						  parent->getTextColour(),
						  Colours::transparentBlack,
						  Colours::transparentBlack,
						  Colours::transparentBlack);

	parent->addChangeListener(this);
	//Call this to set the statusbar text correctly.
	changeListenerCallback(parent);
}

//----------------------------------------------------------------------------
StandardPhilStatusbar::~StandardPhilStatusbar()
{
	deleteAllChildren();
}

//----------------------------------------------------------------------------
void StandardPhilStatusbar::resized()
{
	pathLabel->setBounds(2,
						 ((getHeight()-22)/2),
						 (getWidth()-75),
						 22);
	miscLabel->setBounds((getWidth()-75),
						 ((getHeight()-22)/2),
						 98,
						 22);
}

//----------------------------------------------------------------------------
void StandardPhilStatusbar::changeListenerCallback(void *objectThatHasChanged)
{
	long i;
	long tempint = 0;
	int64 tempint2 = 0;
	float tempf = 0;
	String tempstr(T(""));
	const StringArray& highlights = parent->getCurrentlyHighlightedFiles();

	if(objectThatHasChanged == parent)
	{
		if(highlights.size() == 0)
		{
			pathLabel->setText(parent->getCurrentDirectory().getFullPathName(),
							   false);
			tempint = parent->getNumberOfChildFiles(false);
			tempint += parent->getNumberOfChildFiles(true);
			tempstr.printf(T("(%d files)"), tempint);
			miscLabel->setText(tempstr, false);
		}
		else if(highlights.size() == 1)
		{
			pathLabel->setText(highlights[0], false);
			File fil(highlights[0]);
			if(fil.isDirectory())
			{
				tempint = fil.getNumberOfChildFiles(false);
				tempint += fil.getNumberOfChildFiles(true);
				tempstr.printf(T("(%d files)"), tempint);
			}
			else
			{
				tempint2 = fil.getSize();
				tempint2 /= 1000;
				if(tempint2 > 1000)
				{
					tempf = ((float)tempint2/1000.0f);
					tempstr.printf(T("(%.2f MB)"), tempf);
				}
				else
				{
					tempint = (long)tempint2;
					tempstr.printf(T("(%d kB)"), tempint);
				}
			}
			miscLabel->setText(tempstr, false);
		}
		else if(highlights.size() > 1)
		{
			tempstr = parent->getCurrentDirectory().getFullPathName();
			tempstr << T("(multiple files selected)");
			pathLabel->setText(tempstr,
							   false);
			for(i=0;i<highlights.size();++i)
				tempint2 += File(highlights[i]).getSize();
			tempint2 /= 1000;
			if(tempint2 > 1000)
			{
				tempf = ((float)tempint2/1000.0f);
				tempstr.printf(T("(%.2f MB)"), tempf);
			}
			else
			{
				tempint = (long)tempint2;
				tempstr.printf(T("(%d kB)"), tempint);
			}
			miscLabel->setText(tempstr, false);
		}
	}
}
