//	PhilLookAndFeel.cpp - Custom LookAndFeel to get rid of the horrible title
//						  gradient on the open/save dialogs.
//	----------------------------------------------------------------------------
//	This file is part of the Tracktion-themed Twindy window manager.
//	Copyright (c) 2005-2006 Niall Moody.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//	----------------------------------------------------------------------------

#include <juce.h>
#include "PhilLookAndFeel.h"
#include <iostream>

using namespace std;

//------------------------------------------------------------------------------
PhilLookAndFeel::PhilLookAndFeel():
LookAndFeel()
{
	
}

//------------------------------------------------------------------------------
void PhilLookAndFeel::drawDocumentWindowTitleBar(DocumentWindow& window,
                                           Graphics& g,
										   int w,
										   int h,
                                           int titleSpaceX,
										   int titleSpaceW,
                                           const Image* icon,
                                           bool drawTitleTextOnLeft)
{
    const bool isActive = window.isActiveWindow();

    /*GradientBrush gb (window.getBackgroundColour(),
                      0.0f, 0.0f,
                      window.getBackgroundColour().contrasting (isActive ? 0.15f : 0.05f),
                      0.0f, (float) h, false);
    g.setBrush (&gb);
    g.fillAll();*/
	g.drawLine(2, h, (window.getWidth()-4), h, 1);

    g.setFont (h * 0.65f, Font::bold);

    int textW = g.getCurrentFont().getStringWidth (window.getName());
    int iconW = 0;
    int iconH = 0;

    if (icon != 0)
    {
        iconH = (int) g.getCurrentFont().getHeight();
        iconW = icon->getWidth() * iconH / icon->getHeight() + 4;
    }

    textW = jmin (titleSpaceW, textW + iconW);
    int textX = drawTitleTextOnLeft ? titleSpaceX
                                    : jmax (titleSpaceX, (w - textW) / 2);

    if (textX + textW > titleSpaceX + titleSpaceW)
        textX = titleSpaceX + titleSpaceW - textW;

    if (icon != 0)
    {
        g.setOpacity (isActive ? 1.0f : 0.6f);
        //g.drawImageWithin (icon, textX, (h - iconH) / 2, iconW, iconH, Justification::centredLeft, false, false);
		g.drawImageWithin(icon,
						  textX,
						  (h - iconH) / 2,
						  iconW,
						  iconH,
						  RectanglePlacement(RectanglePlacement::xLeft|RectanglePlacement::centred),
						  false);
        textX += iconW;
        textW -= iconW;
    }

    g.setColour (window.getBackgroundColour().contrasting (isActive ? 0.7f : 0.4f));
    g.drawText (window.getName(), textX, 0, textW, h, Justification::centredLeft, true);
}
